@@ -1,6 +1,7 @@
 import re
 import importlib
 import pip
+import typing as t
 
 # A dictionary of popular module names mapped to their corresponding PyPI packages.
 # TODO: replace this with something more streamlined
@@ -10,6 +11,7 @@ MODULES_TO_PACKAGES = {
     "sklearn": "sklearn",
     "matplotlib": "matplotlib",
     "pandas": "pandas",
+    "ethereumetl": "ethereum-etl",
 }
 
 
@@ -30,7 +32,8 @@ def get_imported_modules(code):
     modules = re.findall(regex, code)
     return modules
 
-def get_missing_modules(code):
+
+def get_missing_modules(code: str) -> t.List[str]:
     imported_modules = get_imported_modules(code)
 
     missing_modules = [
@@ -38,6 +41,7 @@ def get_missing_modules(code):
     ]
     return list(set(missing_modules))
 
+
 def install_missing_packages(code):
     missing_modules = get_missing_modules(code)
 
@@ -45,7 +49,7 @@ def install_missing_packages(code):
     for module in missing_modules:
         package = module_to_pypi_package(module)
         if package is not None:
-            result = pip.main(['install', package])
+            result = pip.main(["install", package])
             if result != 0:
                 unresolved_modules.append(module)
         else:
